// A HighOrderComponent to host the logic we need in order to achieve permissions tracking for an element.
import React from "react";
var elementWithPermissions = function (Component, state) {
    var Permissions = function () {
        // Login data added to props via redux-store (or use react context for example)
        if (!state.userData)
            return React.createElement(React.Fragment, null);
        if (!state.userPermissions)
            return React.createElement(React.Fragment, null);
        var hasPermissions = !!state.userData && state.userPermissions.length > 0;
        var isAdmin = state.userPermissions[0].permission === "superAdmin";
        if (!hasPermissions || !isAdmin)
            return React.createElement(React.Fragment, null);
        // If user is logged in, return original component
        return React.createElement(Component, null);
    };
    return Permissions;
};
export var pageWithPermissions = function (Component, state) {
    var PagePermissions = function () {
        var isWindowDefined = typeof window !== "undefined";
        // If user is not logged in, return an empty component and push to login page
        if (!state.userData && isWindowDefined) {
            // router.push(Redirects.BAD_USER_DATA);
            // return <></>;
            throw new Error("Do not push page - bad data!");
        }
        if (!state.userPermissions)
            return React.createElement(React.Fragment, null);
        var hasPermissions = !!state.userData && state.userPermissions.length > 0;
        var isAdmin = state.userPermissions[0].permission === "superAdmin";
        if (!hasPermissions || !isAdmin) {
            // if (typeof window !== undefined && router.isReady) {
            //   router.push(Redirects.NOT_FOUND);
            // }
            // return <></>;
            throw new Error("Do not push page - bad data!");
        }
        // If user is logged in, return original component
        return React.createElement(Component, null);
    };
    // Copy getInitial props so it will run as well
    if (Component.getInitialProps) {
        PagePermissions.getInitialProps = Component.getInitialProps;
    }
    return PagePermissions;
};
export default elementWithPermissions;
